Administrator's Guide
=====================

If you are a system administrator running Ironic, this section contains
information that may help you understand how to operate and upgrade
the services.

.. toctree::
  :maxdepth: 1

   Drivers, Hardware Types and Hardware Interfaces <drivers>
   Ironic Python Agent <drivers/ipa>
   Node Hardware Inspection <inspection>
   Node Cleaning <cleaning>
   Node Adoption <adoption>
   RAID Configuration <raid>
   Configuring to boot from volume <boot-from-volume>
   Multi-tenant Networking <multitenancy>
   Port Groups <portgroups>
   Configuring Web or Serial Console <console>
   Enabling Notifications <notifications>
   Ceph Object Gateway <radosgw>
   Emitting Software Metrics <metrics>
   Auditing API Traffic <api-audit-support>
   Service State Reporting <gmr>
   Upgrade Guide <upgrade-guide>
   Security <security>
   Troubleshooting FAQ <troubleshooting>

Dashboard Integration
---------------------

A plugin for the OpenStack Dashboard (horizon) service is under development.
Documentation for that can be found within the ironic-ui project.

.. toctree::
  :maxdepth: 1

  Dashboard (horizon) plugin <https://docs.openstack.org/ironic-ui/latest>
